API Reference
=============

.. automodule:: cappr
   :members:
   :undoc-members:
   :show-inheritance:



.. toctree::
   :maxdepth: 4

   cappr.huggingface
   cappr.llama_cpp
   cappr.openai
   cappr.utils
